@@ -1,6 +1,6 @@
 from aomaker.extension.recording.recording import Record
 
 
-addons = [Record('xx.yaml', filter_str='None',
+addons = [Record('xxx.yaml', filter_str='dasdas',
 save_response=True, save_headers=False)]
     
\ No newline at end of file
